Struct amazon_sp_aplus_content::models::aplus_paginated_response::AplusPaginatedResponse
source · [−]pub struct AplusPaginatedResponse {
pub warnings: Option<Vec<Error>>,
pub next_page_token: Option<String>,
}Expand description
AplusPaginatedResponse : The base response data for paginated A+ Content operations. Individual operations may extend this with additional data. If nextPageToken is not returned, there are no more pages to return.
Fields
warnings: Option<Vec<Error>>A set of messages to the user, such as warnings or comments.
next_page_token: Option<String>A page token that is returned when the results of the call exceed the page size. To get another page of results, call the operation again, passing in this value with the pageToken parameter.
Implementations
sourceimpl AplusPaginatedResponse
impl AplusPaginatedResponse
sourcepub fn new() -> AplusPaginatedResponse
pub fn new() -> AplusPaginatedResponse
The base response data for paginated A+ Content operations. Individual operations may extend this with additional data. If nextPageToken is not returned, there are no more pages to return.